==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/kitchen/dialogs_it.lua <==

dialogId("kuch-m-objev0", "font_small", "Oh my, this is a nice kitchen.")
dialogStr("Oh, ma che bella cucina!")

dialogId("kuch-m-objev1", "font_small", "Yeah, we discovered the ship kitchen.")
dialogStr("Già, abbiamo scoperto la cucina di bordo.")

dialogId("kuch-m-objev2", "font_small", "Darned kitchen.")
dialogStr("Maledetta cucina.")

dialogId("kuch-m-objev3", "font_small", "And now we are in the captain Silver`s kitchen.")
dialogStr("E ora ci troviamo nella cucina di Capitan Silver.")

dialogId("kuch-v-varil", "font_big", "I don`t think he was a cook himself.")
dialogStr("Comunque non penso che cucinasse da sè.")

dialogId("kuch-v-problem", "font_big", "But this is not our problem.")
dialogStr("Non è comunque un nostro problema.")

dialogId("kuch-m-noproblem", "font_small", "There are not many problems here. I can swim out at once.")
dialogStr("Non ci sono comunque grossi problemi qui. Io riesco a nuotare via tranquillamente.")

dialogId("kuch-v-podivej", "font_big", "But just have a look at me.")
dialogStr("Dai un'occhiata a me, allora.")

dialogId("kuch-v-stolky0", "font_big", "I can`t understand how these serving tables got there.")
dialogStr("Non capisco come possano essere finiti qui questi tavoli.")

dialogId("kuch-v-stolky1", "font_big", "These tables are in the way.")
dialogStr("Ci sono questi tavoli di mezzo.")

dialogId("kuch-v-stolky2", "font_big", "This little chamber gives me the creeps.")
dialogStr("Questa piccola stanzetta mi fa venire i brividi.")

dialogId("kuch-v-odsud0", "font_big", "I can`t get out of here!")
dialogStr("Non riesco a uscire di qui!")

dialogId("kuch-m-premyslim0", "font_small", "I`m just thinking how to help you.")
dialogStr("Sto pensando a come aiutarti.")

dialogId("kuch-v-odsud1", "font_big", "Help me somehow!")
dialogStr("Dammi un qualche aiuto!")

dialogId("kuch-m-premyslim1", "font_small", "I am thinking...")
dialogStr("Sto pensando...")

dialogId("kuch-m-premyslim2", "font_small", "I am on my way.")
dialogStr("Sto arrivando.")

dialogId("kuch-m-hrnec0", "font_small", "Yuck, there is something left in this pot!")
dialogStr("Bleah! ci sono degli avanzi in questo vasetto!")

dialogId("kuch-m-hrnec1", "font_small", "This pot wasn`t even washed up.")
dialogStr("Questo vaso non è neanche stato lavato.")

dialogId("kuch-m-hrnec2", "font_small", "Nobody washes the dishes here.")
dialogStr("Nessuno lava i piatti qui.")

dialogId("kuch-v-kreslo0", "font_big", "If there was no chair, it would save us a lot of work.")
dialogStr("Se non ci fossero state poltrone, avremmo risparmiato un bel po' di fatica.")

dialogId("kuch-v-ja", "font_big", "Especially myself.")
dialogStr("Soprattutto io.")

dialogId("kuch-m-kreslo0", "font_small", "What is a chair doing in a kitchen?")
dialogStr("Che ci fa una poltrona in cucina?")

dialogId("kuch-v-kreslo1", "font_big", "There should be no chairs in the kitchen.")
dialogStr("Non ci dovrebbero essere potlrone in cucina.")

dialogId("kuch-m-kreslo2", "font_small", "Everybody wants to rest sometimes.")
dialogStr("Tutti hanno bisogno di riposarsi ogni tanto.")

dialogId("kuch-m-stolky", "font_small", "I have seen these tables somewhere.")
dialogStr("Ho già visto questi tavoli da qualche parte.")

dialogId("kuch-v-serie", "font_big", "They are mass-produced, you know.")
dialogStr("Certo, sono prodotti di massa.")

dialogId("kuch-m-pekne", "font_small", "But they are nice. We should order a few too.")
dialogStr("Ma sono carini. Dovremmo anche noi ordinarne qualcuno.")

dialogId("kuch-v-obavam", "font_big", "I am afraid that only I can get out of this space.")
dialogStr("L'unica cosa che mi preme è uscire da questo spazio.")

dialogId("kuch-m-zapeklite", "font_small", "It seems that even this ship contains some demanding problems.")
dialogStr("Sembra che anche questa nave abbia qualche bel rompicapo.")

dialogId("kuch-v-mec", "font_big", "Why is that sword here?")
dialogStr("Cosa ci fa lì quella spada?")

dialogId("kuch-m-porcovani", "font_small", "Maybe they used it to cut the meat.")
dialogStr("Forse la usavano per tagliare la carne.")

dialogId("kuch-v-nedela", "font_big", "Certainly. But you don`t cut meat with a sword in the kitchen, usually.")
dialogStr("Sì. Ma di solito non si taglia la carne con una spada, in cucina.")

dialogId("kuch-m-kuchari", "font_small", "We are lucky there are no cooks here. They could try to cook us.")
dialogStr("Siamo fortunati che non ci siano cuochi. Potrebbero provare a cucinarci.")

dialogId("kuch-v-svitek0", "font_big", "There must be some recipe on that parchment.")
dialogStr("Dev'esserci qualche ricetta su quella pergamena.")

dialogId("kuch-v-svitek1", "font_big", "There must be some culinary mystery on that parchment.")
dialogStr("Quella pergamena deve contenere qualche mistero culinario.")

dialogId("kuch-m-recept", "font_small", "Possibly, how to cook the fish.")
dialogStr("Probabilmente, come cucinare il pesce.")

==> fillets-ng-data_1.0.0.orig.tar.gz: fillets-ng-data-1.0.0/script/kitchen/dialogs_it.lua <==

dialogId("kuch-m-objev0", "font_small", "Oh my, this is a nice kitchen.")
dialogStr("Oh, ma che bella cucina!")

dialogId("kuch-m-objev1", "font_small", "Yeah, we discovered the ship kitchen.")
dialogStr("Già, abbiamo scoperto la cucina di bordo.")

dialogId("kuch-m-objev2", "font_small", "Darned kitchen.")
dialogStr("Maledetta cucina.")

dialogId("kuch-m-objev3", "font_small", "And now we are in the captain Silver’s kitchen.")
dialogStr("E ora ci troviamo nella cucina di Capitan Silver.")

dialogId("kuch-v-varil", "font_big", "I don’t think he was a cook himself.")
dialogStr("Comunque non penso che cucinasse da sè.")

dialogId("kuch-v-problem", "font_big", "But this is not our problem.")
dialogStr("Non è comunque un nostro problema.")

dialogId("kuch-m-noproblem", "font_small", "There are not many problems here. I can swim out at once.")
dialogStr("Non ci sono comunque grossi problemi qui. Io riesco a nuotare via tranquillamente.")

dialogId("kuch-v-podivej", "font_big", "But just have a look at me.")
dialogStr("Dai un'occhiata a me, allora.")

dialogId("kuch-v-stolky0", "font_big", "I can’t understand how these serving tables got there.")
dialogStr("Non capisco come possano essere finiti qui questi tavoli.")

dialogId("kuch-v-stolky1", "font_big", "These tables are in the way.")
dialogStr("Ci sono questi tavoli di mezzo.")

dialogId("kuch-v-stolky2", "font_big", "This little chamber gives me the creeps.")
dialogStr("Questa piccola stanzetta mi fa venire i brividi.")

dialogId("kuch-v-odsud0", "font_big", "I can’t get out of here!")
dialogStr("Non riesco a uscire di qui!")

dialogId("kuch-m-premyslim0", "font_small", "I’m just thinking how to help you.")
dialogStr("Sto pensando a come aiutarti.")

dialogId("kuch-v-odsud1", "font_big", "Help me somehow!")
dialogStr("Dammi un qualche aiuto!")

dialogId("kuch-m-premyslim1", "font_small", "I am thinking...")
dialogStr("Sto pensando...")

dialogId("kuch-m-premyslim2", "font_small", "I am on my way.")
dialogStr("Sto arrivando.")

dialogId("kuch-m-hrnec0", "font_small", "Yuck, there is something left in this pot!")
dialogStr("Bleah! ci sono degli avanzi in questo vasetto!")

dialogId("kuch-m-hrnec1", "font_small", "This pot wasn’t even washed up.")
dialogStr("Questo vaso non è neanche stato lavato.")

dialogId("kuch-m-hrnec2", "font_small", "Nobody washes the dishes here.")
dialogStr("Nessuno lava i piatti qui.")

dialogId("kuch-v-kreslo0", "font_big", "If there was no chair, it would save us a lot of work.")
dialogStr("Se non ci fossero state poltrone, avremmo risparmiato un bel po' di fatica.")

dialogId("kuch-v-ja", "font_big", "Especially myself.")
dialogStr("Soprattutto io.")

dialogId("kuch-m-kreslo0", "font_small", "What is a chair doing in a kitchen?")
dialogStr("Che ci fa una poltrona in cucina?")

dialogId("kuch-v-kreslo1", "font_big", "There should be no chairs in the kitchen.")
dialogStr("Non ci dovrebbero essere potlrone in cucina.")

dialogId("kuch-m-kreslo2", "font_small", "Everybody wants to rest sometimes.")
dialogStr("Tutti hanno bisogno di riposarsi ogni tanto.")

dialogId("kuch-m-stolky", "font_small", "I have seen these tables somewhere.")
dialogStr("Ho già visto questi tavoli da qualche parte.")

dialogId("kuch-v-serie", "font_big", "They are mass-produced, you know.")
dialogStr("Certo, sono prodotti di massa.")

dialogId("kuch-m-pekne", "font_small", "But they are nice. We should order a few too.")
dialogStr("Ma sono carini. Dovremmo anche noi ordinarne qualcuno.")

dialogId("kuch-v-obavam", "font_big", "I am afraid that only I can get out of this space.")
dialogStr("L'unica cosa che mi preme è uscire da questo spazio.")

dialogId("kuch-m-zapeklite", "font_small", "It seems that even this ship contains some demanding problems.")
dialogStr("Sembra che anche questa nave abbia qualche bel rompicapo.")

dialogId("kuch-v-mec", "font_big", "Why is that sword here?")
dialogStr("Cosa ci fa lì quella spada?")

dialogId("kuch-m-porcovani", "font_small", "Maybe they used it to cut the meat.")
dialogStr("Forse la usavano per tagliare la carne.")

dialogId("kuch-v-nedela", "font_big", "Certainly. But you don’t cut meat with a sword in the kitchen, usually.")
dialogStr("Sì. Ma di solito non si taglia la carne con una spada, in cucina.")

dialogId("kuch-m-kuchari", "font_small", "We are lucky there are no cooks here. They could try to cook us.")
dialogStr("Siamo fortunati che non ci siano cuochi. Potrebbero provare a cucinarci.")

dialogId("kuch-v-svitek0", "font_big", "There must be some recipe on that parchment.")
dialogStr("Dev'esserci qualche ricetta su quella pergamena.")

dialogId("kuch-v-svitek1", "font_big", "There must be some culinary mystery on that parchment.")
dialogStr("Quella pergamena deve contenere qualche mistero culinario.")

dialogId("kuch-m-recept", "font_small", "Possibly, how to cook the fish.")
dialogStr("Probabilmente, come cucinare il pesce.")
